# Anomaly Detection for Python

## Introduction

Twitter's Anomaly Detection is easy to use, but it's a R library. 

Although there are some repos for python to run twitter's anomaly detection algorithm, but those libraies requires R installed.

This repo aims for rewriting twitter's Anomaly Detection algorithms in Python, and providing same functions for user.


## Install

```
pip3 install tad
```

